<?php
/**
 * Plugin Name: kevin. Payment Gateway for WooCommerce
 * Plugin URI: https://www.kevin.eu/online-payments/
 * Description: Let your customers make fast, simple and secure payments directly from their bank accounts across Europe.
 * Version: 4.2.8
 * Stable tag: 4.2.8
 * Requires at least: 5.4
 * Tested up to: 6.4
 * Requires PHP: 7.0
 * Author: kevin.
 * Author URI: https://www.kevin.eu/
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: e-commerce-gateway-kevin
 * Domain Path: /languages/
 *
 * WC requires at least: 4.0
 * WC tested up to: 8.4
 */
defined('ABSPATH') || exit;

use KevinPlugin\Bootstrap;
use KevinPlugin\Client\MonitoringClient;

define('WC_KEVIN_PLUGIN_PATH', basename(__DIR__));
define('WC_KEVIN_PLUGIN_URI', plugin_dir_url(__FILE__));
define('WC_KEVIN_MAIN_FILE', __FILE__);

if (version_compare(PHP_VERSION, '7.0.0', '<')) {
	return;
}

//https://github.com/woocommerce/woocommerce/wiki/High-Performance-Order-Storage-Upgrade-Recipe-Book#declaring-extension-incompatibility
add_action('before_woocommerce_init', function() {
    if (class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class)) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);
    }
});

require_once __DIR__.'/vendor/autoload.php';

register_uninstall_hook( __FILE__, 'sendUninstallEvent');
register_activation_hook( __FILE__, 'sendActivationEvent');
register_deactivation_hook( __FILE__, 'sendDeactivationEvent');
add_action('upgrader_process_complete', 'sendUpdateEvent', 10, 2);

add_action('plugins_loaded', [new Bootstrap(), 'load'], 0);

function sendUninstallEvent() {
	(new MonitoringClient())->sendEvent(MonitoringClient::EVENT_UNINSTALLED);
}

function sendActivationEvent() {
	(new MonitoringClient())->sendEvent(MonitoringClient::EVENT_ACTIVATED);
}

function sendDeactivationEvent() {
	(new MonitoringClient())->sendEvent(MonitoringClient::EVENT_DEACTIVATED);
}
function sendUpdateEvent($object, $options) {
	if ($options['action'] !== 'update') {
		return;
	}
	if ($options['type'] !== 'plugin') {
		return;
	}
	if (!isset($options['plugins']) || !is_array($options['plugins'])) {
		return;
	}

	$kevinPluginName = plugin_basename(__FILE__);
	foreach($options['plugins'] as $plugin) {
		if ($plugin === $kevinPluginName) {
			(new MonitoringClient())->sendEvent(MonitoringClient::EVENT_UPDATED);
		}
	}
}