<?php

declare(strict_types=1);

namespace KevinPlugin;

use KevinPlugin\Form\Settings\Subform\MainSettingsSubform;
use KevinPlugin\Gateway\BankPaymentGateway;
use KevinPlugin\Gateway\CardPaymentGateway;
use KevinPlugin\Utils\Translator;

defined('ABSPATH') || exit;

class Bootstrap
{
	const ADMIN_SETTINGS_PATH = 'admin.php?page=wc-settings&tab=checkout&section=getkevin&kevin-tab='.MainSettingsSubform::FORM_ID;

	public function load()
	{
		$this->loadKevinTranslations();

		if (!class_exists('WC_Payment_Gateway')) {
			$this->renderError(Translator::translate('kevin. plugin needs WooCommerce.'));
			return;
		}

        if (version_compare(WC_VERSION, '4.0', '<')) {
            $this->renderError('Minimal required version of WooCommerce for this plugin is 4.0');
            return;
        }

		if (!function_exists('curl_version')) {
			$this->renderError(Translator::translate('PHP cURL extension is disabled. In order for kevin. to work, it must be enabled. Enable it or contact your administrator.'));
			return;
		}

		add_filter('woocommerce_payment_gateways', [$this, 'addKevinPaymentMethod']);
		add_filter('plugin_action_links_'.WC_KEVIN_PLUGIN_PATH.'/getkevin.php', [$this, 'addKevinActionLinks']);
	}

	public function addKevinPaymentMethod($methods)
	{
		$methods[] = BankPaymentGateway::class;
		$methods[] = CardPaymentGateway::class;

		return $methods;
	}

	public function addKevinActionLinks($links)
	{
		$adminSettingsTranslate = Translator::translate('Settings', 'woocommerce');
		$adminSettingsPath = admin_url(self::ADMIN_SETTINGS_PATH);
		$htmlSettingsLink = '<a href="'.$adminSettingsPath.'">'.$adminSettingsTranslate.'</a>';
		array_unshift($links, $htmlSettingsLink);

		return $links;
	}

	public function renderError($error)
	{
		add_action('admin_notices', function () use ($error) {
			$prefix = 'kevin. Payment Gateway for WooCommerce';
			echo '<div class="notice notice-error"><p><b>'.esc_html($prefix).': </b><br>'.esc_html($error).'</p></div>';
		});
	}

	private function loadKevinTranslations()
	{
		load_plugin_textdomain(
			Translator::KEVIN_TRANSLATION_DOMAIN,
			false,
			WC_KEVIN_PLUGIN_PATH.'/languages/'
		);
	}
}
