<?php

declare(strict_types=1);

namespace KevinPlugin\Form\Settings\Subform;

use KevinPlugin\Gateway\BankPaymentGatewaySettings;
use KevinPlugin\Utils\Translator;
use KevinPluginFramework\Presentation\Admin\Form\BuildGuideline\CheckoutSettingsFormBuildGuideline;

defined('ABSPATH') || exit;

class CheckoutSettingsSubform implements SubformInterface
{
    const FORM_ID = 'checkout';

    /**
     * @var string
     */
    private $id = self::FORM_ID;

	/**
	 * @var string
	 */
	private $name;

	/**
	 * @var array[]
	 */
	private $formFields;

	public function __construct(CheckoutSettingsFormBuildGuideline $buildGuideline, BankPaymentGatewaySettings $gatewaySettings)
	{
		$this->name = Translator::translate('Bank payments');

		$formFieldGuidelines = $buildGuideline->getFormFieldBuildGuidelines();

		$this->formFields = [
            //move enabled here from MainSettings
            'enabled' => [
                'title'   => Translator::translate('Enable / Disable'),
                'type'    => 'checkbox',
                'label'   => ' ',
                'default' => 'no',
            ],
            'checkout_view' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_CHECKOUT_VIEW]),
			'country_dropdown' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_COUNTRY_DROPDOWN]),
			'bank_search' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_BANK_SEARCH]),
			'bank_white_logos' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_WHITE_BANK_LOGOS]),
		];
		$this->formFields['checkout_view']['options'] = [
			BankPaymentGatewaySettings::CHECKOUT_VIEW_OPTION_TILES => Translator::translate('Tiles'),
			BankPaymentGatewaySettings::CHECKOUT_VIEW_OPTION_LIST => Translator::translate('List'),
			BankPaymentGatewaySettings::CHECKOUT_VIEW_OPTION_FRAME => Translator::translate('Redirect to bank selection'),
		];
		$this->formFields['country_dropdown']['disabled'] = $gatewaySettings->isCheckoutViewFrame();
		$this->formFields['bank_search']['disabled'] = $gatewaySettings->isCheckoutViewFrame();
		$this->formFields['bank_white_logos']['disabled'] = $gatewaySettings->isCheckoutViewFrame();
	}

	public function getFormFields(): array
	{
		return $this->formFields;
	}

	public function getName(): string
	{
		return $this->name;
	}

    public function getId(): string
    {
        return $this->id;
    }
}
