<?php declare(strict_types=1);

namespace KevinPlugin\Form\Settings\Subform;

use KevinPlugin\Utils\Translator;
use KevinPluginFramework\Presentation\Admin\Form\BuildGuideline\FormFieldBuildGuideline;

defined('ABSPATH') || exit;

class FormFieldBuilder
{
	public static function buildFromGuideline(FormFieldBuildGuideline $guideline): array
	{
		$formField = [
			'title' => Translator::translate($guideline->getTitle()),
			'type' => $guideline->getType(),
			'placeholder' => $guideline->getPlaceholder() ? Translator::translate($guideline->getPlaceholder()) : null,
			'description' => $guideline->getDescription() ? Translator::translate($guideline->getDescription()) : null,
			'desc_tip' => (bool)$guideline->getDescription(),
			'custom_validators' => $guideline->getValidators(),
			'label' => $guideline->getLabel() ? Translator::translate($guideline->getLabel()) : null,
			'options' => $guideline->getOptions()
		];

		if ($guideline->getType() === $guideline::FIELD_TYPE_CHECKBOX) {
			$formField['default'] = $guideline->getDefault() ? 'yes' : 'no';
		} else {
			$formField['default'] = $guideline->getDefault() ? Translator::translate($guideline->getDefault()) : null;
		}

		if ($guideline->isRequired()) {
			$formField['custom_attributes'] =  ['required' => 'required'];
		}

		return $formField;
	}
}
