<?php

declare(strict_types=1);

namespace KevinPlugin\Form\Settings\Subform;

use KevinPlugin\Utils\Translator;
use KevinPluginFramework\Presentation\Admin\Form\BuildGuideline\MainSettingsFormBuildGuideline;

defined('ABSPATH') || exit;

class MainSettingsSubform implements SubformInterface
{
    const FORM_ID = 'main_settings';

    /**
     * @var string
     */
    private $id = self::FORM_ID;

	/**
	 * @var string
	 */
	private $name;

	/**
	 * @var array[]
	 */
	private $formFields;

	public function __construct(MainSettingsFormBuildGuideline $buildGuideline)
	{
		$this->name = Translator::translate($buildGuideline->getName());

		$formFieldGuidelines = $buildGuideline->getFormFieldBuildGuidelines();

		$this->formFields = [
			'client_id' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_CLIENT_ID]),
			'client_secret' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_CLIENT_SECRET]),
			'endpoint_secret' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_ENDPOINT_SECRET]),
			'creditor_name' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_ENDPOINT_CREDITOR_NAME]),
			'creditor_account' => FormFieldBuilder::buildFromGuideline($formFieldGuidelines[$buildGuideline::FIELD_NAME_ENDPOINT_CREDITOR_ACCOUNT]),
		];
	}

	public function getFormFields(): array
	{
		return $this->formFields;
	}

	public function getName(): string
	{
		return $this->name;
	}

    public function getId(): string
    {
        return $this->id;
    }
}
