<?php declare(strict_types=1);

namespace KevinPlugin\Gateway;

use KevinPlugin\Utils\Translator;
use KevinPlugin\View\PaymentReturnView;
use KevinPluginFramework\Application\KevinConstants;

defined('ABSPATH') || exit;

abstract class AbstractPaymentGateway extends \WC_Payment_Gateway
{
    public function render_thankyou_order_received_text($text, $order)
    {
        if (!$order || $this->id !== $order->get_payment_method()) {
            return $text;
        }
        $kevinStatus = sanitize_text_field($_GET['statusGroup'] ?? '');

        if ($kevinStatus === KevinConstants::STATUS_GROUP_COMPLETED) {
            $html = '<div class="woocommerce-message">'.Translator::translate('Thank you for your payment. Your transaction has been completed. You will receive an email with the receipt of your purchase.').'</div>';
        } else {
            $html = '<div class="woocommerce-message" style="background-color: #ffd144;border-color: #ffc000">'.Translator::translate('We will start processing your order once your payment is received.').'</div>';
        }

        return $html;
    }

    public function echo_header_html()
    {
        echo '<h2>' . esc_html($this->get_method_title());
        wc_back_link(__('Return to payments', 'woocommerce'), admin_url( 'admin.php?page=wc-settings&tab=checkout'));
        echo '</h2>';
    }

    /**
     * prefix added to form post data by woocommerce
     */
    protected function getFormFieldPrefix(): string
    {
        return $this->plugin_id . $this->id . '_';
    }

    protected function extractSettingsFormData(): array
    {
        $formData = [];
        foreach ($this->get_post_data() as $key => $value) {
            if (substr($key, 0, strlen($this->getFormFieldPrefix())) === $this->getFormFieldPrefix()) {
                $key = str_replace($this->getFormFieldPrefix(), '', $key);
                $formData[$key] = $value;
            }
        }
        return $formData;
    }
}