<?php

declare(strict_types=1);

namespace KevinPlugin\Gateway;

defined('ABSPATH') || exit;

class BankPaymentGatewaySettings
{
	const CHECKOUT_VIEW_OPTION_TILES = 'tiles';
	const CHECKOUT_VIEW_OPTION_LIST = 'list';
	const CHECKOUT_VIEW_OPTION_FRAME = 'frame';

	private $enabled;
	private $clientId;
	private $clientSecret;
	private $creditorName;
	private $creditorAccount;
	private $endpointSecret;
	private $checkoutView;
	private $countryDropdown;
	private $bankSearch;
    private $bankWhiteLogos;

    public function __construct(array $settings)
	{
		$this->enabled = ($settings['enabled'] ?? null) === 'yes';
		$this->clientId = $settings['client_id'] ?? null;
		$this->clientSecret = $settings['client_secret'] ?? null;
		$this->endpointSecret = $settings['endpoint_secret'] ?? null;
		$this->creditorName = $settings['creditor_name'] ?? null;
		$this->creditorAccount = $settings['creditor_account'] ?? null;
		$this->checkoutView = $settings['checkout_view'] ?? null;
		$this->countryDropdown = ($settings['country_dropdown'] ?? null) === 'yes';
		$this->bankSearch = ($settings['bank_search'] ?? null) === 'yes';
		$this->bankWhiteLogos = ($settings['bank_white_logos'] ?? null) === 'yes';
	}

	public function isEnabled(): bool
	{
		return $this->enabled;
	}

    /**
     * @return string|null
     */
	public function getClientId()
	{
		return $this->clientId;
	}

    /**
     * @return string|null
     */
	public function getClientSecret()
	{
		return $this->clientSecret;
	}

    /**
     * @return string|null
     */
	public function getCreditorName()
	{
		return $this->creditorName;
	}

    /**
     * @return string|null
     */
	public function getCreditorAccount()
	{
		return $this->creditorAccount;
	}

    /**
     * @return string|null
     */
	public function getEndpointSecret()
	{
		return $this->endpointSecret;
	}

	/**
	 * @return string|null
	 */
	public function getCheckoutView()
	{
		return $this->checkoutView;
	}

	public function isCheckoutViewFrame(): bool
	{
		return $this->getCheckoutView() === self::CHECKOUT_VIEW_OPTION_FRAME;
	}

	public function isCheckoutViewList(): bool
	{
		return $this->getCheckoutView() === self::CHECKOUT_VIEW_OPTION_LIST;
	}

	public function isCheckoutViewTiles(): bool
	{
		return $this->getCheckoutView() === self::CHECKOUT_VIEW_OPTION_TILES;
	}

	public function isCountryDropdown(): bool
	{
		return $this->countryDropdown;
	}

	public function isBankSearch(): bool
	{
		return $this->bankSearch;
	}

    public function isBankWhiteLogos(): bool
    {
        return $this->bankWhiteLogos;
    }
}
