<?php

declare(strict_types=1);

namespace KevinPlugin\Handler;

use KevinPlugin\Client\GatewayClient;
use KevinPlugin\Utils\KevinInfoMessage;
use KevinPlugin\Utils\Translator;
use KevinPlugin\Utils\Url;

defined('ABSPATH') || exit;

class RefundHandler
{

	/**
	 * @var GatewayClient
	 */
	private $client;

	public function __construct(GatewayClient $client)
	{
		$this->client = $client;
	}

	public function handle(\WC_Order $order, float $amount, string $reason)
	{
		$paymentId = $order->get_meta('_kevin_id');
		if (!$paymentId) {
			return new \WP_Error('error', Translator::translate('Refund failed.'));
		}

		$amount = number_format($amount, 2);

		$attr = [
			'amount' => $amount,
			'Webhook-URL' => Url::generateWebhookUrl(),
		];

		try {
			$response = $this->client->initPaymentRefund($paymentId, $attr);
		} catch (\Exception $exception) {
			$order->add_order_note(
				KevinInfoMessage::withPrefix(
					sprintf(Translator::translate('Refund failed: %s'), $exception->getMessage())
				)
			);

			return new \WP_Error('error', sprintf(Translator::translate('Refund failed: %s'), $exception->getMessage()));
		}

		if (!$response) {
			return new \WP_Error('error', Translator::translate('Refund failed.'));
		}

		$order->add_order_note(
			KevinInfoMessage::withPrefix(sprintf(
				Translator::translate('Starting refund process. Amount %s, Payment ID: %s, Reason: %s'),
				wc_price($amount, ['currency' => $order->get_currency()]), $paymentId, $reason
				)
			)
		);

		return true;
	}
}
