<?php

declare(strict_types=1);

namespace KevinPlugin\Repository;

use KevinPlugin\Utils\Server;

defined('ABSPATH') || exit;

class OrderRepository
{
	/**
	 * @param $paymentId
	 * @return \WC_Order|null
	 */
	public function findOneByPaymentId($paymentId)
	{
		$attr = [
			'meta_key' => '_kevin_id',
			'meta_value' => $paymentId,
			'meta_compare' => '=',
		];

		$orders = wc_get_orders($attr);

		return $orders[0] ?? null;
	}

	/**
	 * @param $orderId
	 * @return bool|\WC_Order|\WC_Order_Refund
	 */
	public function findByOrderId($orderId)
	{
		return wc_get_order($orderId);
	}

    public function updateOrderWithKevinMetadata(\WC_Order $order, array $kevinApiResponse, string $returnUrlToken)
    {
        $order->update_meta_data('_kevin_id', $kevinApiResponse['id']);
        $order->update_meta_data('_kevin_ip_address', $order->get_customer_ip_address());
        $order->update_meta_data('_kevin_ip_port', Server::getCustomerIpPort());
        $order->update_meta_data('_kevin_user_agent', $order->get_customer_user_agent());
        $order->update_meta_data('_kevin_status', $kevinApiResponse['bankStatus'] ?? $kevinApiResponse['cardStatus'] ?? $kevinApiResponse['hybridStatus']);
        $order->update_meta_data('_kevin_status_group', $kevinApiResponse['statusGroup']);
        $order->update_meta_data('_kevin_return_token', $returnUrlToken);
        $order->save();
    }

    public function updateOrderMetadataKevinReturnStatusGroup(\WC_Order $order, string $statusGroup)
    {
        $order->update_meta_data('_kevin_return_status_group', $statusGroup);
        $order->save();
    }
}
