<?php

declare(strict_types=1);

namespace KevinPlugin\Utils;

use KevinPlugin\PluginConfig;

class Url
{
	public static function generateWebhookUrl(): string
	{
        $webhookUrl = add_query_arg(['wc-api' => 'WC_Gateway_GetKevin'], home_url('/'));
        $scheme = wp_parse_url($webhookUrl, PHP_URL_SCHEME);
		if ($scheme !== 'https' && Url::isUrlAccessible(home_url('/', 'https'))) {
            $webhookUrl = add_query_arg(['wc-api' => 'WC_Gateway_GetKevin'], home_url('/', 'https'));
		}

		if (PluginConfig::CUSTOM_WEBHOOK_URL()) {
			$webhookUrl = str_replace(get_home_url(), PluginConfig::CUSTOM_WEBHOOK_URL(), $webhookUrl);
		}

		return (string)filter_var($webhookUrl, FILTER_SANITIZE_URL);
	}

    public static function generateReturnUrl($returnUrlToken): string
    {
        $url = add_query_arg(['wc-api' => 'kevin_return', 'kv_wc_tkn' => $returnUrlToken], home_url('/'));

        if (PluginConfig::CUSTOM_RETURN_URL()) {
            $url = str_replace(home_url('/'), PluginConfig::CUSTOM_RETURN_URL(), $url);
        }

        return (string)filter_var($url, FILTER_SANITIZE_URL);
    }

	public static function generateUrlToFile($relativePath): string
	{
		return plugins_url($relativePath, WC_KEVIN_MAIN_FILE);
	}

    public static function isUrlAccessible($url)
    {
        $curlInit = curl_init($url);
        curl_setopt($curlInit,CURLOPT_CONNECTTIMEOUT,1);
        curl_setopt($curlInit,CURLOPT_TIMEOUT,2);
        curl_setopt($curlInit,CURLOPT_HEADER,true);
        curl_setopt($curlInit,CURLOPT_NOBODY,true);
        curl_setopt($curlInit,CURLOPT_RETURNTRANSFER,true);

        $response = curl_exec($curlInit);
        $httpCode = curl_getinfo($curlInit, CURLINFO_HTTP_CODE);

        curl_close($curlInit);

        return $response && ($httpCode >= 200 && $httpCode < 300);
    }
}
