<?php

declare(strict_types=1);

namespace KevinPlugin\View;

use KevinPlugin\Client\GatewayClient;
use KevinPlugin\PluginConfig;
use KevinPlugin\Gateway\BankPaymentGatewaySettings;
use KevinPlugin\Utils\Url;

class BankPaymentView
{
	const TEMPLATE_PATH = __DIR__ . '/../../templates/kevin-bank-payment-view.php';

	/**
	 * @var BankPaymentGatewaySettings
	 */
	protected $gatewaySettings;
	/**
	 * @var bool
	 */
	protected $isBankPaymentOption;
	/**
	 * @var bool
	 */
	protected $isCardPaymentOption;
	/**
	 * @var array
	 */
	protected $countries;
	/**
	 * @var string
	 */
	protected $defaultCountryCode;
	/**
	 * @var array
	 */
	protected $banks;

	public function __construct(GatewayClient $gatewayClient, BankPaymentGatewaySettings $gatewaySettings)
	{
		$this->gatewaySettings = $gatewaySettings;
		$this->countries = $this->prepareCountries($gatewayClient->getKevinCountries());
		$this->defaultCountryCode = $this->getDefaultCountryCode();
		$this->banks = $gatewayClient->getKevinBanks($gatewaySettings->isBankWhiteLogos());
	}

	public function render()
	{
		include self::TEMPLATE_PATH;

		wp_register_style('kevin_styles', Url::generateUrlToFile('assets/css/kevin-styles.css'), [], PluginConfig::PLUGIN_VERSION());
		wp_enqueue_style('kevin_styles');

		if ($this->gatewaySettings->isCheckoutViewTiles()) {
			wp_register_style('kevin_bank_grid', Url::generateUrlToFile('assets/css/kevin-bank-grid.css'), [], PluginConfig::PLUGIN_VERSION());
			wp_enqueue_style('kevin_bank_grid');
            if ($this->gatewaySettings->isBankWhiteLogos()) {
                wp_register_style('kevin_bank_grid_white', Url::generateUrlToFile('assets/css/kevin-bank-grid-white-logos.css'), [], PluginConfig::PLUGIN_VERSION());
                wp_enqueue_style('kevin_bank_grid_white');
            }
		} elseif ($this->gatewaySettings->isCheckoutViewList()) {
			wp_register_style('kevin_bank_list', Url::generateUrlToFile('assets/css/kevin-bank-list.css'), [], PluginConfig::PLUGIN_VERSION());
			wp_enqueue_style('kevin_bank_list');
		}

		wp_register_script('kevin_frontend_script', Url::generateUrlToFile('assets/js/frontend/kevin-checkout.js'), [], PluginConfig::PLUGIN_VERSION());
		wp_enqueue_script('kevin_frontend_script');
	}

    private function prepareCountries(array $kevinCountries): array
    {
        asort($kevinCountries);
        $countries = [];
        foreach ($kevinCountries as $countryCode) {
            $countries[$countryCode] = WC()->countries->countries[$countryCode];
        }
        return $countries;
    }

    private function getDefaultCountryCode(): string
    {
        $defaultCountryCode = WC()->customer ? WC()->customer->get_billing_country() : null;
        return $defaultCountryCode ?: wc_get_base_location()['country'];
    }
}
