<?php

declare(strict_types=1);

namespace KevinPlugin\View;

use KevinPlugin\Client\GatewayClient;
use KevinPlugin\Form\Settings\Subform\CheckoutSettingsSubform;
use KevinPlugin\Form\Settings\Subform\MainSettingsSubform;
use KevinPlugin\Gateway\BankPaymentGateway;
use KevinPlugin\Gateway\CardPaymentGateway;
use KevinPlugin\Utils\Translator;

class CardPaymentSettingsFormView extends AbstractSettingsView
{
	const TEMPLATE_PATH = __DIR__.'/../../templates/kevin-card-settings-form-view.php';

    /**
     * @var GatewayClient|null
     */
    private $gatewayClient;
    /**
     * @var CardPaymentGateway
     */
    private $cardPaymentGateway;

    public function __construct(CardPaymentGateway $cardPaymentGateway, $gatewayClient)
	{
        $this->gatewayClient = $gatewayClient;
        $this->cardPaymentGateway = $cardPaymentGateway;
    }

	public function render()
	{
		include self::TEMPLATE_PATH;
	}

	protected function generateSettingsHtml(): string
	{
		return $this->cardPaymentGateway->generate_settings_html($this->cardPaymentGateway->form_fields, false);
	}

    protected function getBankPaymentCredentialsSettingsUrl(): string
    {
        return admin_url( 'admin.php?page=wc-settings&tab=checkout&section='.BankPaymentGateway::GATEWAY_ID.'&kevin-tab='.MainSettingsSubform::FORM_ID);
    }

    protected function getBankPaymentCheckoutSettingsUrl(): string
    {
        return admin_url( 'admin.php?page=wc-settings&tab=checkout&section='.BankPaymentGateway::GATEWAY_ID.'&kevin-tab='.CheckoutSettingsSubform::FORM_ID);
    }

	protected function getInfoMessages(): array
	{
        if (!$this->cardPaymentGateway->isGatewayReady()) {
			return [];
		}
        $shopSettingMessage = $this->boldHtmlText(Translator::translate('Your shop settings from kevin. dashboard:')) . ' ';
		if ($this->gatewayClient->isCardPaymentEnabled()) {
			$shopSettingMessage .= Translator::translate('Card payment method is available.');
		} else {
            $shopSettingMessage .= Translator::translate('Card payment method is not available.');
        }
        $shopSettingMessage .= ' ';
		if ($this->gatewayClient->isRefundByCardEnabled()) {
			$shopSettingMessage .= Translator::translate('Card refunds are allowed.');
		} else {
            $shopSettingMessage .= Translator::translate('Card refunds are not allowed.');
        }

		return [$shopSettingMessage];
	}

	protected function getWarningMessages(): array
	{
		if (!$this->cardPaymentGateway->isGatewayReady()) {
			return [];
		}

		$messages = [];

		if ($this->gatewayClient->isSandbox()) {
			$messages[] = Translator::translate('kevin. payment gateway is in test mode for testing purposes. Real payments are not available.');
		}

		return $messages;
	}

    protected function getErrorMessages(): array
    {
        if (!$this->gatewayClient) {
            return [];
        }

        $messages = [];

        if (!$this->gatewayClient->getKevinProjectSettings()) {
            $messages[] = Translator::translate('Incorrect client credentials.');
        }

        return $messages;
    }
}
