<?php

namespace KevinPluginFramework\Application;

use Kevin\KevinException;
use KevinPluginFramework\Application\Exception\KevinRequestBadRequestException;
use KevinPluginFramework\Application\Exception\KevinRequestException;
use KevinPluginFramework\Application\Exception\KevinRequestInternalServerException;
use KevinPluginFramework\Application\Exception\KevinRequestUnauthorizedException;

class PaymentClientRequestExceptionFactory
{
    /**
     * @param KevinException $e
     * @return KevinRequestBadRequestException|KevinRequestException|KevinRequestInternalServerException|KevinRequestUnauthorizedException
     */
    public static function createFromKevinException($e)
    {
        if ($e->getCode() === 401) {
            return new KevinRequestUnauthorizedException($e);
        }
        if ($e->getCode() >= 400 && $e->getCode() < 500) {
            return new KevinRequestBadRequestException($e);
        }
        if ($e->getCode() >= 500 && $e->getCode() < 600) {
            return new KevinRequestInternalServerException($e);
        }

        return new KevinRequestException($e);
    }

}
