<?php

namespace KevinPluginFramework\Presentation\Admin\Form\BuildGuideline;

class CheckoutSettingsFormBuildGuideline implements FormBuildGuidelineInterface
{
    const FIELD_NAME_CHECKOUT_VIEW = 'checkout_view';
    const FIELD_NAME_COUNTRY_DROPDOWN = 'country_dropdown';
    const FIELD_NAME_BANK_SEARCH = 'bank_search';
    const FIELD_NAME_WHITE_BANK_LOGOS = 'white_bank_logos';

    const CHECKOUT_VIEW_OPTION_TILES = 'tiles';
    const CHECKOUT_VIEW_OPTION_LIST = 'list';
    const CHECKOUT_VIEW_OPTION_FRAME = 'frame';

    private $name = 'Checkout view';

    /**
     * @var FormFieldBuildGuideline[]
     */
    private $guidelines;

    public function __construct()
    {
        $this->guidelines = [
            self::FIELD_NAME_CHECKOUT_VIEW => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_CHECKOUT_VIEW)
                ->setTitle('Select checkout view')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_SELECT)
                ->setLabel('Select checkout view')
				->setDescription('Choose the one that suits best your storefront design.')
                ->setOptions([
                    self::CHECKOUT_VIEW_OPTION_TILES => 'Tiles',
                    self::CHECKOUT_VIEW_OPTION_LIST => 'List',
                    self::CHECKOUT_VIEW_OPTION_FRAME => 'Redirect to bank selection',
                ]),
            self::FIELD_NAME_COUNTRY_DROPDOWN => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_COUNTRY_DROPDOWN)
                ->setTitle('Country select dropdown')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('Show country selection dropdown on the checkout page.')
                ->setDefault(1),
            self::FIELD_NAME_BANK_SEARCH => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_BANK_SEARCH)
                ->setTitle('Bank search field')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('Show the bank search field on the checkout page.')
                ->setDefault(1),
            self::FIELD_NAME_WHITE_BANK_LOGOS => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_WHITE_BANK_LOGOS)
                ->setTitle('White bank logos')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('If selected, bank logos will be shown in white (good for a dark theme)')
                ->setDefault(0),
        ];
    }

    public function getFormFieldBuildGuidelines()
    {
        return $this->guidelines;
    }

    public function getName()
    {
        return $this->name;
    }
}
