<?php

namespace KevinPluginFramework\Presentation\Admin\Form\BuildGuideline;

use KevinPluginFramework\Presentation\Admin\Form\Validator\CreditorNameRegexValidator;
use KevinPluginFramework\Presentation\Admin\Form\Validator\IbanRegexValidator;
use KevinPluginFramework\Presentation\Admin\Form\Validator\NotBlankValidator;

class MainSettingsFormBuildGuideline implements FormBuildGuidelineInterface
{
    const FIELD_NAME_ENABLED = 'enabled';
    const FIELD_NAME_CLIENT_ID = 'client_id';
    const FIELD_NAME_CLIENT_SECRET = 'client_secret';
    const FIELD_NAME_ENDPOINT_SECRET = 'endpoint_secret';
    const FIELD_NAME_ENDPOINT_CREDITOR_NAME = 'creditor_name';
    const FIELD_NAME_ENDPOINT_CREDITOR_ACCOUNT = 'creditor_account';

    private $name = 'Main settings';

    /**
     * @var array
     */
    private $guidelines;

    public function __construct()
    {
        $this->guidelines = [
            self::FIELD_NAME_ENABLED => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_ENABLED)
                ->setTitle('Enable / Disable')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('Enable kevin.')
                ->setDefault(0),
            self::FIELD_NAME_CLIENT_ID => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_CLIENT_ID)
                ->setTitle('Client ID')
                ->setDescription('Your Client ID from kevin. dashboard.')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_TEXT)
                ->setRequired(true)
                ->setValidators([
                    new NotBlankValidator()
                ]),
            self::FIELD_NAME_CLIENT_SECRET => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_CLIENT_SECRET)
                ->setTitle('Client Secret')
                ->setDescription('Your Client Secret from kevin. dashboard.')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_PASSWORD)
                ->setRequired(true)
                ->setValidators([
                    new NotBlankValidator(),
                ]),
            self::FIELD_NAME_ENDPOINT_SECRET => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_ENDPOINT_SECRET)
                ->setTitle('Endpoint Secret')
                ->setDescription('Your Endpoint Secret from kevin. dashboard.')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_PASSWORD)
                ->setRequired(true)
                ->setValidators([
                    new NotBlankValidator(),
                ]),
            self::FIELD_NAME_ENDPOINT_CREDITOR_NAME => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_ENDPOINT_CREDITOR_NAME)
                ->setTitle('Receiver name')
                ->setDescription('Receiver name should contain only Latin characters and numbers.')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_TEXT)
                ->setRequired(true)
                ->setValidators([
                    new NotBlankValidator(),
                    new CreditorNameRegexValidator()
                ]),
            self::FIELD_NAME_ENDPOINT_CREDITOR_ACCOUNT => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_ENDPOINT_CREDITOR_ACCOUNT)
                ->setTitle('Receiver bank account')
                ->setDescription('The IBAN must be the same as the one stated in the agreement.')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_TEXT)
                ->setRequired(true)
                ->setValidators([
                    new NotBlankValidator(),
                    new IbanRegexValidator()
                ]),
        ];
    }

    public function getFormFieldBuildGuidelines()
    {
        return $this->guidelines;
    }

    public function getName()
    {
        return $this->name;
    }
}
